/*  ---------------------------------------------------------------------------
    Program  :  ReMakeShoesDS.sas

    Author   :  Perry Watts
    Date     :  01Jun2010 11:40

    Purpose  :  Shorten the sashelp.shoes data set so that it is amenable to
                PROC FREQ and PROC REPORT

    Input    :  sashelp.shoes
    Output   :  styleApp.shoes2 (for PROC FREQ) STYLAPP.shoes3 (FOR PROC REPORT)

    Notes    :  DON'T EXECUTE!! DATA SETS ALREADY EXIST.  THIS PROGRAM IS 
                INCLUDED TO SHOW HOW THE DATA SETS WERE CREATED!! 
    ------------------------------------------------------------------------  */

   %MACRO SKIP;
    libname styleApp "...";
    title1;
    data shoes2(keep=product subsidiary stores rename=(stores=nstores));
      set sashelp.shoes;
      if product in ('Boot','Sandal','Slipper','Sport Shoe');
    run;

    proc sort data=shoes2 out=styleApp.shoes2;
      by product subsidiary;
    run;

    proc print data=styleApp.shoes2(obs=7);
      var product subsidiary nstores;
    run;
  /* *****
 Obs    Product    Subsidiary     nstores

   1     Boot      Addis Ababa       12
   2     Boot      Al-Khobar         10
   3     Boot      Algiers           21
   4     Boot      Auckland          12
   5     Boot      Bangkok            1
   6     Boot      Bogota            19
   7     Boot      Budapest          22

      ***** */

    proc freq data=styleApp.shoes2;
     weight nstores;
     tables product;
    run;
  /* *****
                        The FREQ Procedure

                                        Cumulative    Cumulative
 Product       Frequency     Percent     Frequency      Percent
 ---------------------------------------------------------------
 Boot               864       30.44           864        30.44
 Sandal             564       19.87          1428        50.32
 Slipper            794       27.98          2222        78.29
 Sport Shoe         616       21.71          2838       100.00

      ***** */

   data shoes3(keep=Product Subsidiary Stores Sales Returns rename=(stores=nstores));
     set sashelp.shoes;
     if product in ('Boot','Sandal','Slipper','Sport Shoe');
     if subsidiary in ('Cairo','Montreal','Moscow','New York');
   run;

   proc sort data=shoes3 out=styleApp.shoes3;
     by product subsidiary;
   run;

   proc print data=styleApp.shoes3;
     var product subsidiary nstores Sales Returns;
   run;

  /* *****
Obs    Product       Subsidiary    nstores           Sales         Returns

  1    Boot           Cairo           20            $4,846            $229
  2    Boot           Montreal        25           $40,213          $1,472
  3    Boot           Moscow          23           $67,476          $3,142
  4    Boot           New York        18           $97,151          $3,983
  5    Sandal         Cairo            9           $10,532            $598
  6    Sandal         Montreal         7            $3,002            $122
  7    Sandal         New York         1              $554             $23
  8    Slipper        Cairo            9           $13,732          $1,216
  9    Slipper        Montreal        24          $135,305          $3,395
 10    Slipper        Moscow          11          $127,033          $3,983
 11    Slipper        New York        24          $252,758          $8,503
 12    Sport Shoe     Cairo            3            $2,259             $44
 13    Sport Shoe     Montreal        31           $29,435          $1,129
 14    Sport Shoe     Moscow          23           $21,464            $859
 15    Sport Shoe     New York        23           $22,190            $847
     ***** */
%MEND SKIP;
