/*  ---------------------------------------------------------------------------
    Program  :  UseCLASSstmt.sas

    Author   :  Perry Watts
    Date     :  Monday, January 03, 2011

    Project  :  ODS Styles Paper for SGF with 9.2 SAS

    Purpose  :  Show how the CLASS statement works in new style definitions.
   
    Notes    :  Replace my subdirectory structure with yours!!

    Input    :  styleApp.shoes2
    Output   :  HTML files:
    ------------------------------------------------------------------------  */
    libname Styleapp "C:\ETC";
    %let htmPath=c:\ETC;
    ods path work.temp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);

  /* Example #1: STYLES.DEFAULT */
    ods html path="&htmPath" (url=none)
      file='default.html' style=STYLES.DEFAULT;
      title 'Default Template Output';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;

  /* EXAMPLE #2: CHANGE JUST ONE ATTRIBUTE FOR HEADER AND INHERIT THE REST.*/ 
    proc template;
      define style styles.ChangeHeader1;
      parent=styles.default;
      class header /
        font=(arial, 14pt, bold);
      end;
    run;
   ods html path="&htmPath" (url=none)
      file='ChangeHeader1.html' style=ChangeHeader1;
      title 'Font Size for HEADER and ROWHEADER Increases with a CLASS statement';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;


 /* EXAMPLE #3: CHANGE NON-LINEAGE ATTRIBUTES: BORDERWIDTH AND BORDERCOLOR. */
    proc template;
      define style styles.NonLineageAttrs;
      parent=styles.default;
      class Header/
        font=(arial, 14pt, bold)
        borderwidth=3
        bordercolor=colors('headerfg');
      end; 
    run;
    ods html path="&htmPath" (url=none)
      file='NonLineageAttrs.html' style=NonLineageAttrs;
      title 'Non-lineage attributes BORDERWIDTH and BORDERCOLOR are added to HEADER';
      footnote;
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;
    ods listing;
     
  ODS TAGSETS.STYLE_POPUP path="&htmpath" 
    FILE='StyleDiag.HTML' style=NonLineageAttrs;
    title "Use Dx Tagsets on Non-Lineage Attrs";
     proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
     run;
    ods _all_ close;
 
  /* *****
         Here is the text listing of the POPUP window:
          STYLE Header /
           FONT_FACE = "arial"
           FONT_SIZE = 14pt
           FONT_WEIGHT = bold
           FONT_STYLE = roman
           FOREGROUND = cx0033aa
           BACKGROUND = cxb0b0b0
           BORDERWIDTH = NaN (???)
         ;
        BORDERCOLOR IS NOT LISTED.  IT DOESN'T COUNT AS FOREGROUND. THAT IS FOR THE TEXT.
        I CHECKED BY MAKING BORDERCOLOR BLACK.
       
      ***** */

   /* EXAMPLES 4A AND 4B:
      CHANGING THE ORDER OF TWO CLASSES FROM THE SAME LINEAGE HAS NO EFFECT ON THE OUTCOME*/ 
    proc template;
      define style styles.TwoClassesA;
      parent=styles.default;
      class header /
        font=(arial, 14pt, bold)
        color=red;
      class rowheader /
        color=blue;
      end;
    run;
   ods html path="&htmPath" (url=none)
      file='TwoClassesA.html' style=TwoClassesA;
      title 'Correct Lineage Order: HEADER -> ROWHEADER';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;

   proc template;
      define style styles.TwoClassesB;
      parent=styles.default;
      class rowheader /
        color=blue;
      class header /
        font=(arial, 14pt, bold)
        color=red;
      end;
    run;
   ods html path="&htmPath" (url=none)
      file='TwoClassesB.html' style=TwoClassesB;
      title 'Wrong Lineage Order: ROWHEADER -> HEADER is Corrected';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;

 /* EXAMPLE #5: INTRODUCE TWO CLASSES EXCLUSIVELY FROM BASE.TEMPLATE.STYLE 
    INTO A NEW STYLE DEFINITION. */
    proc template;
      define style styles.BaseOnlyClass;
      parent=styles.default;
      class HeadersAndFooters/
        font=(arial, 12pt, bold)
        borderwidth=2
        bordercolor=colors('headerfg');
      class systemTitle2 / 
        foreground=black
        fontStyle=roman
        fontSize=12pt;
      class systemTitle3 / fontSize=10pt;
      end; 
    run;
    ods html path="&htmPath" (url=none)
      file='BaseOnlyClass.html' style=BaseOnlyClass;
      title 'The SYSTEMTITLEn Classes are NOT in the ODS Styles.Default Template';
      title2 'Instead, they are defined in Base.Template.Style';
      title3 'Base.Template.Style is "the implicit parent for all style templates"';
      footnote;
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;
    ods listing;

    /* EXAMPLE #6: CHANGE FONTS WITH A CLASS STATEMENT. */
    proc template;
      define style styles.OneFontChange;
            parent=styles.default;
      CLASS fonts /
        'docFont'=("Courier",3,Bold);
      end;
    run;
   ods html path="&htmPath" (url=none)
      file='OneFontChange.html' style=OneFontChange;
      title 'Only DOCFONT affecting the DATA Style Element has been Changed';
      title2 'Titles and Headers Retain their Default Fonts';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;
