/*  ---------------------------------------------------------------------------
    Program  :  UseSTYLEwNOfrom.sas

    Author   :  Perry Watts
    Date     :  Tuesday, December 14, 2010

    Project  :  ODS Styles Paper for SGF with 9.2 SAS

    Purpose  :  Show the effect of issuing a STYLE statement without a
                from option.

    Notes    :  Replace my subdirectory structure with yours!!

    Input    :  styleApp.shoes2
    Output   :  HTML files:

    Revised  :  Press Alt+D
    ------------------------------------------------------------------------  */
    libname Styleapp "C:\ETC";
    %let htmPath=c:\ETC;
    ods path work.temp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);

  /* EXAMPLE #7: STYLE FONTS */ 
    proc template;
      define style styles.OneFontChangeWstyle;
            parent=styles.default;
      STYLE fonts /
        'docFont'=("Courier",3,Bold);
      end;
    run;
 
   ods html path="&htmPath" (url=none)
      file='OneFontChangeWstyle.html' style=OneFontChangeWstyle;
      title 'DOCFONT is Used by All Style Elements in PROC FREQ Output';
      title2 '(Including Titles and Headers)';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;

  /* EXAMPLE #8: STYLE CONTAINER 
     All STYLE ELEMENTS IN CONTAINER ARE CHANGED. TITLES AND PROC TITLES REMAIN LIGHT GRAY. */
    proc template;
      define style styles.ChangeContainer1;
        parent=styles.default;
        STYLE Container /
          FONT = Fonts('DocFont')
          COLOR = colors('docfg')
          BACKGROUNDCOLOR = CXEFF3FF
          TEXTDECORATION = underline;
      end;
    run;
 
   ods html path="&htmPath" (url=none)
      file='ChangeContainer1.html' style=ChangeContainer1;
      title 'Change CONTAINER with a STYLE Statement';
      title2 '(Original attributes are assigned values. TEXTDECORATION is added.)';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;

  /* EXAMPLE #8A: EXAMPLE #8 IS FIXED
     All STYLE ELEMENTS IN CONTAINER ARE CHANGED. TITLES AND PROC TITLES ARE LIGHT BLUE*/
    proc template;
      define style styles.ChangeContainer1a;
        parent=styles.default;
        STYLE Container /
          FONT = Fonts('DocFont')
          COLOR = colors('docfg')
          BACKGROUNDCOLOR = CXEFF3FF
          TEXTDECORATION = underline;
        Class TitlesAndFooters /
          BACKGROUNDCOLOR = CXEFF3FF;
        Class ProcTitle /
          BACKGROUNDCOLOR = CXEFF3FF;
      end;
    run;
 
   ods html path="&htmPath" (url=none)
      file='ChangeContainer1a.html' style=ChangeContainer1a;
      title 'Change CONTAINER with a STYLE Statement';
      title2 'The Background Color of the Title and PROC Areas Now Match CONTAINER';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;

 /* EXAMPLE #9: CONTAINER HAS NO ATTRIBUTES */
   proc template;
      define style styles.ChangeContainer2;
        parent=styles.default;
        STYLE Container;
       end;
    run;
 
   ods html path="&htmPath" (url=none)
      file='ChangeContainer2.html' style=ChangeContainer2;
      title 'Change CONTAINER with a STYLE Statement';
      title2 'NO Attributes are Specified for CONTAINER';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;

 /* EXAMPLE #10: HEADER HAS NO BACKGROUND COLOR */
   proc template;
      define style styles.ChangeHeader;
        parent=styles.default;
        style Header/
          FONT = fonts('HeadingFont')
          COLOR = BLACK;
       end;
    run;
 
   ods html path="&htmPath" (url=none)
      file='ChangeHeader.html' style=ChangeHeader;
      title 'Change HEADER with a STYLE Statement';
      title2 'A Background Color is NOT Specified.';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
   ods _all_ close;
