/*  ---------------------------------------------------------------------------
    Program  :  UseStyleWITHfrom.sas

    Author   :  Perry Watts
    Date     :  Monday, January 03, 2011

    Project  :  ODS Styles Paper for SGF with 9.2 SAS

    Purpose  :  When LINEAGES are altered in a new STYLE definition, you need a
                FROM clause.

    Input    :  styleApp.shoes2
    Output   :  HTML files written out to \AlterLineages

    Notes    :  Replace my subdirectory structure with yours!!
    ------------------------------------------------------------------------  */
    libname Styleapp "C:\ETC";
    %let htmPath=c:\ETC;
    ods path work.temp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);
  /* EXAMPLE #11
     HEADER IS CHANGED, ROW-HEADER TAKES THE DEFAULTS: USE ZENDER's EXAMPLES ON PAGE 9
     FROM HER "ALWAYS IN FASHION" PAPER. */
    proc template;
      define style styles.ChangeHeaderOnly;
      parent=styles.default;
      class header /
        font=(arial, 14pt, bold)
        foreground=blue;
      style rowHeader FROM headersAndFooters;
      end;
    run;
   ods html path="&htmPath" (url=none)
      file='ChangeHeaderOnlyLINEAGE.html' style=ChangeHeaderOnlyLINEAGE;
      title 'Restore Defaults to ROWHEADER with a LINEAGE Change';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;


/* EXAMPLE #12: 
   INHERIT FROM A DISTANT ANCESTOR  
   INHERIT HEADER BACKGROUND COLOR FROM CONTAINER (bypassing CELL HEADERSANDFOOTERS) */  
   proc template;
     define style styles.HeaderFromContainer;
      parent=styles.default;
      style HEADER from CONTAINER /
       FONT = fonts('HeadingFont')
       COLOR = BLACK;
     end;
   run;
   ods html path="&htmPath" (url=none)
      file='HeaderFromContainer.html' style=HeaderFromContainer;
      title1 'Inherit from a Distant Ancestor: CONTAINER -> HEADER';
      title2 '(Bypass CELL and HEADERSANDFOOTERS)';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;

/* EXAMPLE #13: 
   INHERIT FROM DESCENDENT */  
  proc template;
    define style styles.HeaderFromRowHeader;
    parent=styles.default;
    style rowheader from headersAndFooters /
      font = (arial,12pt,bold)
      foreground=blue;
    style header from rowheader /
      foreground=red;
    end; 
  run;
  ods html path="&htmPath" (url=none)
    file='HeaderFromRowHeader.html' 
    style=HeaderFromRowHeader;
    title "INHERIT FROM A DESCENDENT";
    title2 "HEADERSANDFOOTERS -> ROWHEADER -> HEADER";
    proc freq data=styleApp.shoes2;
      weight nstores;
      tables product;
    run;
  ods _all_ close;

  /* EXAMPLE #14:
     MAKE HEADERS AND DATA LOOK THE SAME WITH A TWO LINEAGE SOLUTION.
     WE WILL SEE A SINGLE LINEAGE SOLUTION NEXT.
  */
    proc template;
      define style styles.HdrDataFromContainer;
      parent=styles.default;
      class CONTAINER /
        font=(arial, 14pt, bold)
        foreground=black;
      style HEADER from CONTAINER;
      style DATA from CONTAINER;
      end;
    run;
   ods noptitle;
   ods html path="&htmPath" (url=none)
      file='HdrDataFromContainer.html' style=HdrDataFromContainer;
      title1 'Inherit from a Distant Ancestor: CONTAINER -> HEADER';
      title2 'Then from the same Ancestor to a Different Lineage: CONTAINER -> DATA';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;

  /* EXAMPLE #15:
     OUTPUT->HEADERSANDFOOTERS->DATA (FOR A COMPLETELY UNIFORM TABLE) WITH A SINGLE LINEAGE */
   proc template;
     define style styles.Output2HandF2Data;
      parent=styles.default;
      class output /
        backgroundcolor=colors('docbg')
        bordercolor=colors('docfg')
        borderwidth=2
        borderspacing=2;
      style headersAndFooters from Output;
      style data from headersAndFooters;
      style systemTitle from headersAndFooters /
        padding=0
        borderwidth=0
        borderspacing=0;
      style procTitle from systemTitle;
     end;
    run;
    ods proctitle;
    ods html path="&htmPath" (url=none)
      file='Output2HandF2Data.html' style=Output2HandF2Data;
      title1 'Get Uniform Output with Cross-Lineage Inheritance';
      title2 'OUTPUT -> HEADERSANDFOOTERS -> DATA -> SYSTEMTITLE -> PROCTITLE';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;


  /* EXAMPLE #16:
     FROM THE SECTION: "CREATE A STYLE THAT EMBODIES COLOR PRINCIPLES DESCRIBED IN THE PAPER"
     THE ALL-BLUE STYLE */
    proc template;
    define style styles.BlueOutput;
     parent=styles.default;
     class Container /
       backgroundcolor = cxEFF3FF;
     class HeadersAndFooters /
       color=cxEFF3FF  
       fontsize=12pt
       backgroundcolor=cx00269A;
     class Output /
       backgroundcolor=cxEFF3FF
       bordercolor=colors('docfg')
       borderwidth=2 borderspacing=2;
     style Data from Output /
       color=colors('docfg') 
       backgroundcolor=cxEFF3FF;
     class SystemTitle /
       backgroundcolor = cxEFF3FF 
       fontStyle=roman 
       fontSize=14pt;
     class SystemTitle2 /
       fontSize=12pt;
    end;
   run;
   ods noptitle;
   ods html path="&htmPath" (url=none)
      file='BlueOutput.html' style=BlueOutput;
      title1 'Final Output uses Three Shades of the Same Blue';
      title2 'Only One STYLE...FROM Statement is Required';
      proc freq data=styleApp.shoes2;
        weight nstores;
        tables product;
      run;
    ods _all_ close;
