/*  ---------------------------------------------------------------------------
    Program  :  UsingOtherProcsByDefault.sas

    Author   :  Perry Watts
    Date     :  Thursday, December 09, 2010

    Project  :  ODS Styles Paper for SGF with 9.2 SAS

    Purpose  :  Show how ODS classes are inserted by default into PROC PRINT,
                PROC FREQ, and PROC MEANS.

    Notes    :  Subdivisions:
                1) Defaults: MEANS, PRINT (FREQ ALREADY COVERED EARLIER IN PAPER)
                   For Proc Print, show what happens with NOOBS and ID.
                2) The special case of JUST - highlighting out-of-lineage ATTRIBUTES
                    PLUS the notion "The PROC wins".
                Replace my subdirectory structure with yours!!

    Input    :  styleApp.shoes2 and SASHELP files
    Output   :  HTML files:
    ------------------------------------------------------------------------  */
    libname Styleapp "C:\ETC";
    %let htmPath=c:\ETC;
    ods path work.temp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);

  /* FIGURE 8 */
    ods html path="&htmPath" (url=none)
    file='defaultOtherProcs.html' style=STYLES.default;
      title 'PROC MEANS with Automatic Style Element Mapping';
      title2 '(Only HEADER is Used by Default)';
      proc means data=sashelp.heart maxdec=3;
        var Height Weight Diastolic Systolic;
      run;

      title 'PROC PRINT with Automatic Style Element Mapping';
      title2 '(HEADER and ROWHEADER are Used by Default)';
      proc print data=styleApp.shoes2(obs=7) label;
      run;

      title 'PROC PRINT with Automatic Style Element Mapping';
      title2 '(ROWHEADER is Erased with NOOBS)';
      proc print data=styleApp.shoes2(obs=7) noobs label;
      run;

      title 'PROC PRINT with Automatic Style Element Mapping';
      title2 '(ROWHEADER is Restored with ID)';
      proc print data=sashelp.class(obs=7) noobs label;
        ID Name;
      run;
    ods _all_ close;
    ods listing;
  
  /* FIGURE 9: 
     THE SPECIAL CASE OF JUST. HERE IS WHERE PROCS AND ODS CLASH 
     IN THIS EXAMPLE, ONLY OUT-OF-LINEAGE ATTRIBUTES ARE
     ADDED(CELLWIDTH,JUST). WITH 'CLASS', LINEAGE REMAINS FIXED. */

   proc template;
     define style styles.FreqJust;
     parent=styles.default;
     class header/
       cellwidth=1in 
       just=left;  /* GET RIGHT */
     class rowheader/
       just=right; /* GET LEFT */
     end;
   run;
   ods html path="&htmPath" (url=none)
     file='FreqJust.html' 
     style=FreqJust;
     title 'JUST Fails in PROC FREQ for HEADER and ROWHEADER'; 
     title2 'GET LEFT___________________________________________GET RIGHT';
     proc freq data=styleApp.shoes2;
       weight nstores;
       tables product;
     run;
   ods _all_ close;
