/*  ---------------------------------------------------------------------------
    Program  :  UsingProcReport.sas

    Author   :  Perry Watts
    Date     :  Friday, December 10, 2010

    Project  :  ODS Styles Paper for SGF with 9.2 SAS

    Purpose  :  Show how ODS classes work with PROC REPORT.

    Notes    :  Subdivisions:
                1) Default Mappings of STYLE ELEMENTS for PROC REPORT.
                2) Use Style(Column)= to achieve mappings.
                3) Create a new style with new NAMES (and by necessity, with FROM).
                Replace my subdirectory structure with yours!!

    Input    :  styleApp.shoes3
    Output   :  HTML files:
    ------------------------------------------------------------------------  */
    libname Styleapp "C:\ETC";
    %let htmPath=c:\ETC;
    ods path work.temp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);

    data shoes4;
      set styleApp.shoes3;
      if product in('Boot','Sandal');
    run;
    data shoes4wMissVal;
      set shoes4;
      if product eq 'Boot' and subsidiary eq 'Montreal' then 
        returns=.;
    run;

  /* FIGURE 10: AUTOMATIC MAPPING*/
    ods html path="&htmPath" (url=none) 
    body='defaultProcReport1.html' 
    style=STYLES.Default;
    proc report data=shoes4wMissVal nowindows;
      column Product Subsidiary nstores Sales Returns;
      Define Product    / ORDER;
      Define Subsidiary / ORDER;
      Define nStores    / display '# Stores';
      Define Sales      / display format=dollar8.;
      Define Returns    / display format=dollar8.;
      title 'PROC REPORT with an Automatic Mapping for the HEADER';
    run;
    ods HTML close;

/* FIGURE 11: STYLE(COLUMN) with STANDARD-NAMED STYLE ELEMENTS */
    ods html path="&htmPath" (url=none) 
    body='defaultProcReport2.html' 
    style=STYLES.Default;
    proc report data=shoes4wMissVal nowindows split='*';
     column Product Subsidiary nstores Sales Returns;
     Define Product    / ORDER 'Product*ROWHEADER' 
                         STYLE(COLUMN)=ROWHEADER;
     Define Subsidiary / ORDER 'Subsidiary*ROWHEADEREMPHASIS' 
                         STYLE(COLUMN)=ROWHEADEREMPHASIS;
     Define nStores    / display '# Stores';
     Define Sales      / display format=dollar8.;
     Define Returns    / display format=dollar8.;
     title 'Two Columns are Formatted with Style Element Overrides';
    run;
    ods HTML close;

  /* FIGURE 12: CREATE A STYLE TEMPLATE WITH USER-DEFINED NAMES USING STYLE...FROM*/
   proc template;
   define style styles.ColumnsOutput;
   parent=styles.default;
    style Hdr from Header;
    style RowHdr from RowHeader;  
    style RowHdrEmph from RowHeaderEmphasis;
    style RowHdrEmphFx from RowHeaderEmphasisFixed;
    class SystemTitle2 / fontSize=10pt;
    class dataEmpty / backgroundcolor=colors('headerfg') color=colors('headerbg');
   end; 
   run;
   proc format;
     value RetFmt .='Missing' other=[dollar8.];
   run;
   ods html path="&htmPath" (url=none)
   body='ColumnsOutput.HTML' 
   style=ColumnsOutput;
    proc report
    data=shoes4wMissVal nowindows nowindows split='*';
     column Product Subsidiary nstores Sales Returns;
     Define Product    / ORDER 'Product*(Hdr)' STYLE(COLUMN)=Hdr;
     Define Subsidiary / ORDER 'Subsidiary*(RowHdr)' STYLE(COLUMN)=RowHdr;
     Define nStores    / display '# Stores*(RowHdrEmph)' STYLE(COLUMN)=RowHdrEmph ;
     Define Sales      / display 'Total Sales*(RowHdrEmphFx)' format=dollar8. STYLE(COLUMN)=RowHdrEmphFx;                        
     Define Returns    / display 'Total Returns*DATA(default)*OR*DATAEMPTY(missing)' format=RetFmt.;
     compute Returns;
       if Returns eq . then
         call define ('_c5_', "style", "style=DataEmpty");
     endcomp;
     title  'PROC REPORT with Abbreviated Hdr...RowHdrEmphFx for Lineage #20 ';
     title2 '#20 Trace: Hdr->RowHdr->RowHdrEmph->RowHdrEmphFx';
     title3 'Colors for the MISSING Value in RETURNS come from DATAEMPTY';
    run;
    ods HTML close;

  
